@@ -3,7 +3,6 @@ function(x, ...) {
 cat("Call:\n")
 print(x$call)
 cat("\n")
-cat(paste("  Number of DIF groups:",x$ng,"\n\n"))
 cat(paste("  Number of items flagged for DIF:",sum(x$flag),"of",x$ni,"\n\n"))
 cat(paste("  Items flagged:",paste(which(x$flag),collapse=", "),"\n\n"))
 cat(paste("  Number of iterations for purification:",x$iteration,"of",x$options$maxIter,"\n\n"))
@@ -20,7 +19,7 @@ if (sum(x$flag)>0) {
 out<-switch(toupper(x$options$criterion),
 "CHISQR"=c("chi12","chi13","chi23"),
             "R2"=switch(toupper(x$options$pseudo.R2),
-"MCFADDEN"=c("pseudo12.McFadden","pseudo13.McFadden","pseudo23.McFadden"),
+"MCFADDEN"=c("pseudo12.McFadden","psudo13.McFadden","pseudo23.McFadden"),
 "NAGELKERKE"=c("pseudo12.Nagelkerke","pseudo13.Nagelkerke","pseudo23.Nagelkerke"),
 "COXSNELL"=c("pseudo12.CoxSnell","pseudo13.CoxSnell","pseudo23.CoxSnell")),
 "BETA"="beta12")
